.. hierarch documentation master file, created by
   sphinx-quickstart on Wed May 26 14:11:33 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

hierarch documentation
====================================

This is the hierarch documentation. Please start with the User Manual.

.. toctree::
   :maxdepth: 3
   :caption: Table of Contents

   user/index.rst
   reference/index.rst